#
# spec file for package python-eventlet
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-eventlet
Version:        0.20.0
Release:        lp151.4.3
Summary:        Concurrent networking library for Python
License:        MIT
Group:          Development/Languages/Python
Url:            http://eventlet.net
Source:         https://files.pythonhosted.org/packages/source/e/eventlet/eventlet-%{version}.tar.gz
Patch0:         0001-Fix-SSL-connection-reset-errors.patch
# PATCH-FIX-UPSTREAM PR-459.patch -- https://github.com/eventlet/eventlet/pull/459
Patch1:         PR-459.patch
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module greenlet}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %python_version_nodots < 34
Requires:       python-enum34
%endif
# eventlet parses /etc/protocols which is not available in normal build envs
Requires:       netcfg
Requires:       python-greenlet >= 0.3
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
Eventlet is a concurrent networking library for Python that allows
changing how code is run.

It uses epoll or libevent for scalable non-blocking I/O. Coroutines
ensure that the developer uses a blocking style of programming that is similar
to threading, but provide the benefits of non-blocking I/O. The event dispatch
is implicit, which means Eventlet can be used from the Python
interpreter, or as part of a larger application.

%package doc
Summary:        Documentation for the Eventlet concurrent networking library
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}

%description doc
Documentation for Eventlet, which is a concurrent networking library
for Python that allows changing how code is run.

%prep
%setup -q -n eventlet-%{version}
%patch0 -p1
%patch1 -p1
sed -i '/enum.compat/d' setup.py # crude way to drop the strange "enum-compat" requirement
sed -i "s|^#!.*||" eventlet/support/greendns.py # Fix non-executable script

%build
%python_build
%python_exec setup.py build_sphinx && rm build/sphinx/html/.buildinfo

%install
%python_install
%fdupes %{buildroot}%{_prefix}

%files %{python_files}
%defattr(-,root,root,-)
%doc AUTHORS LICENSE NEWS README.rst
%{python_sitelib}/*

%files %{python_files doc}
%defattr(-,root,root,-)
%doc build/sphinx/html examples

%changelog
* Fri Jan 12 2018 tbechtold@suse.com
- Add PR-459.patch.
  Hostname in /etc/hosts are not case-sensitive, this fixes
  HostsResolver() accordingly.
* Sun Dec 10 2017 dmueller@suse.com
- fix enum-compat removal
* Sun Nov 26 2017 dmueller@suse.com
- go back to a working version: downgrade to 0.20.0
- add  0001-Fix-SSL-connection-reset-errors.patch to fix
  hangs on SSL connections
* Tue Oct 17 2017 snica@suse.com
- add netcfg package to list of requirements
* Fri Oct  6 2017 tbechtold@suse.com
- update to 0.21.0:
  * New timeout error API: .is_timeout=True on exception object
    It's now easy to test if network error is transient and retry is
    appropriate.
    Please spread the word and invite other libraries to support this interface.
  * hubs: use monotonic clock by default (bundled package);
  * dns: EVENTLET_NO_GREENDNS option is back, green is still default
  * dns: hosts file was consulted after nameservers
  * ssl: RecursionError on Python3.6+;
  * wsgi: log_output=False was not disabling startup and accepted messages
  * greenio: Fixed OSError: [WinError 10038] Socket operation on nonsocket
  * dns: EAI_NODATA was removed from RFC3493 and FreeBSD
  * green.select: fix mark_as_closed() wrong number of args
  * green.zmq: socket.{recv,send}_* signatures did not match recent
    upstream pyzmq
  * New feature: Add zipkin tracing to eventlet
  * db_pool: proxy Connection.set_isolation_level()
  * green.zmq: support RCVTIMEO (receive timeout)
  * green.profile: Python3 compatibility; Thanks to Artur Stawiarski
  * support: upgrade bundled six to 1.10 (dbfbfc818e3d)
  * python3.6: http.client.request support chunked_encoding
- Use fdupes
* Tue Sep  5 2017 jengelh@inai.de
- Ensure neutrality of description.
* Tue Sep  5 2017 jmatejek@suse.com
- remove dependency on metapackage "enum-compat" in favor of
  specifying this requirement the usual way via RPM requirement
  conditional on version
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Wed Jan 11 2017 dmueller@suse.com
- update to 0.20.1:
  * dns: try unqualified queries as top level
  * test_import_patched_defaults bended to play with pyopenssl>=16.1.0
  * Explicit environ flag for importing eventlet.__version__ without ignoring import errors
  * Type check Semaphore, GreenPool arguments; Thanks to Matthew D. Pagel
  * IMPORTANT: removed select.poll() function
  * DNS resolving is always green with dnspython bundled in
  * greenio: only trampoline when we block
  * convenience: listen() sets SO_REUSEPORT when available; Thanks to Zhengwei Gao
  * ssl: Fix "TypeError: read() argument 2 must be read-write bytes-like object, not None"
  * greenio: _recv_loop behaviour with recv_into on closed sock
  * ipv6: getaddrinfo would fail with scope index
  * green.zmq: Support {send,recv}_{string,json,pyobj} wrappers
  * greendns: Return answers from /etc/hosts despite nameserver errors
  * patcher: fixed green existing locks fail (Python3)
  * Add DAGPool, a dependency-driven greenthread pool
  * wsgi: Unix socket address representation; Thanks to Samuel Merritt
  * tpool: isolate internal socket from default timeout; Thanks to Alex Villacís Lasso
  * wsgi: only skip Content-Type and Content-Length headers (GH-327)
  * wsgi: 400 on blank Content-Length headers (GH-334)
  * greenio: makefile related pypy socket ref counting
  * ssl: Fix recv_into blocking when reading chunks of data
  * websocket: support Gunicorn environ['gunicorn.socket']
* Sat Dec  3 2016 dmueller@suse.com
- update to 0.19.0:
  * ssl: IMPORTANT DoS FIX do_handshake_connect=False in server accept();
  * green.urllib2: missing patched ssl module;
  * wsgi: environ[headers_raw] tuple of unmodified name: value pairs
  * test against modern pyopenssl 16.0.0 for Python 2.7+;
  * wsgi: document compatibility with python `logging`
  * Minor grammatical improvements and typo fixes to the docs
* Fri Feb 26 2016 dmueller@suse.com
-  update to 0.18.4:
  * wsgi: change TCP_NODELAY to TCP_QUICKACK, ignore socket error when not available
  * wsgi: Use buffered writes - fixes partial socket.send without custom
    writelines(); Github issue #295
  * wsgi: TCP_NODELAY enabled by default
  * wsgi: Fix data loss on partial writes (socket.send); Thanks to Jakub Stasiak
  * IMPORTANT: do not use Eventlet 0.18.0 and 0.18.1
  * patcher: Fix AttributeError in subprocess communicate()
  * greenio: Fix "TypeError: an integer is required" in sendto()
  * IMPORTANT: do not use Eventlet 0.18.0 and 0.18.1
  * greenio: Fixed a bug that could cause send() to start an endless loop on
    ENOTCONN; Thanks to Seyeong Kim
  * wsgi: Fixed UNIX socket address being trimmed in "wsgi starting" log; Thanks
    to Ihar Hrachyshka
  * ssl: Ported eventlet.green.OpenSSL to Python 3; Thanks to Victor Stinner
  * greenio: Made read() support buflen=-1 and added readall() (Python 3);
    Thanks to David Szotten
  * wsgi: Made the error raised in case of chunk read failures more precise (this
    should be backwards compatible as the new exception class,
    wsgi.ChunkReadError, is a subclass of ValueError which was being used there
    before); Thanks to Samuel Merritt
  * greenio: Fixed socket.recv() sometimes returning str instead of bytes on
    Python 3; Thanks to Janusz Harkot
  * wsgi: Improved request body discarding
  * websocket: Fixed TypeError on empty websocket message (Python 3); Thanks to
    Fukuchi Daisuke
  * subprocess: Fixed universal_newlines support
  * wsgi: Output of 0-byte chunks is now suppressed; Thanks to Samuel Merritt
  * Improved the documentation; Thanks to Ramakrishnan G, ashutosh-mishra and
    Azhar Hussain
  * greenio: Changed GreenFileIO.write() (Python 3) to always write all data to
    match the behavior on Python 2; Thanks to Victor Stinner
  * subprocess: Fixed missing subprocess.mswindows attribute on Python 3.5;
    Thanks to Josh VanderLinden
  * ssl/monkey patching: Fixed a bug that would cause merely importing eventlet
    to monkey patch the ssl module; Thanks to David Szotten
  * documentation: Added support for building plain text documentation; thanks
    to Levente Polyak
* Mon Jun 22 2015 tbechtold@suse.com
- update to 0.17.4:
  * ssl: incorrect initalization of default context; Thanks to stuart-mclaren
* Wed Apr 22 2015 tbechtold@suse.com
- update to 0.17.3:
  * green.thread: Python3.3+ fixes; Thanks to Victor Stinner
  * Semaphore.acquire() accepts timeout=-1; Thanks to Victor Stinner
  * wsgi: Provide python logging compatibility; Thanks to Sean Dague
  * greendns: fix premature connection closing in DNS proxy; Thanks to
    Tim Simmons
  * greenio: correct fd close; Thanks to Antonio Cuni and Victor Sergeyev
  * green.ssl: HTTPS client Python 2.7.9+ compatibility
  * setup: tests.{isolated,manual} polluted top-level packages
  * greendns: fix dns.name import and Python3 compatibility
* Tue Feb 24 2015 tbechtold@suse.com
- update to version 0.17.0
  * Full Python3 compatibility
  * greendns: IPv6 support, improved handling of /etc/hosts
  * tpool: make sure we return results during killall
  * semaphore: Don't hog a semaphore if someone else is waiting for it
  * green.socket: create_connection() was wrapping all exceptions
    in socket.error
  * Make sure SSL retries are done using the exact same data buffer
  * greenio: shutdown already closed sockets without error
* Mon Feb  2 2015 tbechtold@suse.com
- update to version 0.16.1:
  * Wheel build 0.16.0 incorrectly shipped removed module eventlet.util.
* Thu Jan  8 2015 tbechtold@suse.com
- update to 0.16.0:
  * Fix SSL socket wrapping and Python 2.7.9 compatibility; Thanks to Jakub Stasiak
  * Fix monkey_patch() on Python 3; Thanks to Victor Stinner
  * Fix "maximum recursion depth exceeded in GreenSocket.__del__"; Thanks to Jakub Stasiak
  * db_pool: BaseConnectionPool.clear updates .current_size #139; Thanks to Andrey Gubarev
  * Fix __str__ method on the TimeoutExpired exception class.; Thanks to Tomaz Muraus
  * hubs: drop Twisted support
  * Removed deprecated modules: api, most of coros, pool, proc, processes and util
  * Improved Python 3 compatibility (including patch by raylu); Thanks to Jakub Stasiak
  * Allow more graceful shutdown of wsgi server; Thanks to Stuart McLaren
  * wsgi.input: Make send_hundred_continue_headers() a public API; Thanks to Tushar Gohad
  * tpool: Windows compatibility, fix ResourceWarning. Thanks to Victor Stinner
  * tests: Fix timers not cleaned up on MySQL test skips; Thanks to Corey Wright
- Remove README.twisted from docs (removed upstream)
* Tue Sep  2 2014 dmueller@suse.com
- update to 0.15.2:
  * greenio: fixed memory leak, introduced in 0.15.1; Thanks to Michael Kerrin, Tushar Gohad
  * wsgi: Support optional headers w/ "100 Continue" responses; Thanks to Tushar Gohad
  * greenio: Fix second simultaneous read (parallel paramiko issue); Thanks to Jan Grant, Michael Kerrin
  * db_pool: customizable connection cleanup function; Thanks to Avery Fay
  * Python3 compatibility -- **not ready yet**; Thanks to Astrum Kuo, Davanum Srinivas, Jakub Stasiak, Victor Sergeyev
  * coros: remove Actor which was deprecated in 2010-01
  * saranwrap: remove saranwrap which was deprecated in 2010-02
  * PyPy compatibility fixes; Thanks to Dmitriy Kruglyak, Jakub Stasiak
  * green.profile: accumulate results between runs; Thanks to Zhang Hua
  * greenthread: add .unlink() method; Thanks to Astrum Kuo
  * packaging: Generate universal wheels; Thanks to Jakub Stasiak
  * queue: Make join not wait if there are no unfinished tasks; Thanks to Jakub Stasiak
  * tpool: proxy __enter__, __exit__ fixes Bitbucket-158; Thanks to Eric Urban
  * websockets: Add websockets13 support; handle lack of Upgrade header; Thanks to Edward George
  * wsgi: capitalize_response_headers option
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Sep 17 2013 dmueller@suse.com
- update to 0.14.0:
  * wsgi: handle connection socket timeouts; Thanks to Paul Oppenheim
  * wsgi: close timed out client connections
  * greenio: socket pypy compatibility; Thanks to Alex Gaynor
  * wsgi: env['wsgi.input'] was returning 1 byte strings; Thanks to Eric Urban
  * green.ssl: fix NameError; Github #17; Thanks to Jakub Stasiak
  * websocket: allow "websocket" in lowercase in Upgrade header; Compatibility with current Google Chrome; Thanks to Dmitry Orlov
  * wsgi: allow minimum_chunk_size to be overriden on a per request basis; Thanks to David Goetz
  * wsgi: configurable socket_timeout
* Wed Jul  3 2013 dmueller@suse.com
- update to 0.13.1:
  * hubs: kqueue support! Thanks to YAMAMOTO Takashi, Edward George
  * greenio: Fix AttributeError on MacOSX; Bitbucket #136; Thanks to Derk Tegeler
  * green: subprocess: Fix subprocess.communicate() block on Python 2.7; Thanks to Edward George
  * green: select: ensure that hub can .wait() at least once before timeout; Thanks to YAMAMOTO Takashi
  * tpool: single request queue to avoid deadlocks; Bitbucket pull request 31,32; Thanks to Edward George
  * zmq: pyzmq 13.x compatibility; Thanks to Edward George
  * green: subprocess: Popen.wait() accepts new `timeout` kwarg; Python 3.3 and RHEL 6.1 compatibility
  * hubs: EVENTLET_HUB can point to external modules; Thanks to Edward George
  * semaphore: support timeout for acquire(); Thanks to Justin Patrin
  * support: do not clear sys.exc_info if can be preserved (greenlet >= 0.3.2); Thanks to Edward George
  * Travis continous integration; Thanks to Thomas Grainger, Jakub Stasiak
  * wsgi: minimum_chunk_size of last Server altered all previous (global variable); Thanks to Jakub Stasiak
  * doc: hubs: Point to the correct function in exception message; Thanks to Floris Bruynooghe
* Fri Feb  8 2013 p.drouand@gmail.com
- Update to version 0.12.1:
  * zmq: Fix 100%% busy CPU in idle after .bind(PUB)
  * greenio: Fix socket.settimeout() did not switch back to blocking mode
  * greenio: socket.dup() made excess fcntl syscalls
  * setup: Remove legacy --without-greenlet option and unused httplib2 dependency
  * wsgi: environ[REMOTE_PORT], also available in log_format, log accept event
  * tests: Support libzmq 3.0 SNDHWM option
* Tue Jan 15 2013 p.drouand@gmail.com
- Update to version 0.11.0:
  * ssl: Fix 100%% busy CPU in socket.sendall() (thanks to Raymon Lu)
  * zmq: Return linger argument to Socket.close() (thanks to Eric Windisch)
  * tests: SSL tests were always skipped due to bug in skip_if_no_ssl decorator
* Fri Nov 23 2012 saschpe@suse.de
- Update to version 0.9.17:
  + ZeroMQ support calling send and recv from multiple greenthreads
  + SSL: unwrap() sends data, and so it needs trampolining
  + hubs.epolls: Fix imports for exception handler
  + db_pool: Fix .clear() when min_size > 0
  + db_pool: Add MySQL's insert_id() method
  + db_pool: Close connections after timeout, fix get-after-close race
    condition with using TpooledConnectionPool
  + threading monkey patch fixes
  + pools: Better accounting of current_size in pools.Pool
  + wsgi: environ['RAW_PATH_INFO'] with request path as received from client
  + wsgi: log_output flag
  + wsgi: Limit HTTP header size
  + wsgi: Configurable maximum URL length
* Fri Sep  2 2011 saschpe@suse.de
- Update to version 0.9.16:
  + SO_REUSEADDR now correctly set.
- Don't package unittests
- Fix non-executable script rpmlint warning
* Wed Feb  2 2011 berendt@b1-systems.de
- bumped version to 0.9.14
* Fri Nov 26 2010 seife+obs@b1-systems.com
- initial package (version 0.9.9)
